autowisp.database.hdf5_file_structure module — AutoWISP documentation

# autowisp.database.hdf5_file_structure module

## Class Inheritance Diagram

Define HDF5 file setting its structure from a database.

class autowisp.database.hdf5_file_structure.HDF5FileDatabaseStructure(fname=None, mode=None, layout_version=None, **kwargs)

  Bases: `HDF5File`

  HDF5 file with structure specified through the database.

  property elements

    HDF5File.elements for description.

    Type:

      See

    Type:

      meth

  classmethod get_file_structure(version=None)

    See :meth:HDF5File.get_file_structure for description.